import { TBreakpoint, TBreakpoints, TLayout, TResponsiveLayout } from '@/components/Grid/layout-definition';
/**
 * Given breakpoints, return an array of breakpoints sorted by width. This is usually
 * e.g. ['xxs', 'xs', 'sm', ...]
 *
 * @param  {Object} breakpoints Key/value pair of breakpoint names to widths.
 * @return {Array}              Sorted breakpoints.
 */
export declare const sortBreakpoints: (breakpoints: TBreakpoints) => TBreakpoint[];
/**
 * Given a width, find the highest breakpoint that matches is valid for it (width > breakpoint).
 *
 * @param  {Object} breakpoints Breakpoints object (e.g. {lg: 1200, md: 960, ...})
 * @param  {Number} width Screen width.
 * @return {String}       Highest breakpoint that is less than width.
 */
export declare const getBreakpointFromWidth: (breakpoints: TBreakpoints, width: number) => TBreakpoint;
/**
 * Given a breakpoint, get the # of cols set for it.
 * @param  {String} breakpoint Breakpoint name.
 * @param  {Object} cols       Map of breakpoints to cols.
 * @return {Number}            Number of cols.
 */
export declare const getColsFromBreakpoint: (breakpoint: TBreakpoint, cols: TBreakpoints) => number;
/**
 * Given existing layouts and a new breakpoint, find or generate a new layout.
 *
 * This finds the layout above the new one and generates from it, if it exists.
 *
 * @param  {TLayout}       orgLayout         Original layout.
 * @param  {Object}        layouts           Existing layouts.
 * @param  {TBreakpoints}  breakpoints       All breakpoints.
 * @param  {TBreakpoint}   breakpoint        New breakpoint.
 * @param  {TBreakpoint}   lastBreakpoint    Last breakpoint (for fallback).
 * @param  {Number}        cols              Column count at new breakpoint.
 * @param  {Boolean}       verticalCompact   Whether or not to compact the layout vertically.
 * @return {TLayout}                         New layout.
 */
export declare const findOrGenerateResponsiveLayout: (orgLayout: TLayout, layouts: TResponsiveLayout, breakpoints: TBreakpoints, breakpoint: TBreakpoint, lastBreakpoint: TBreakpoint, cols: number, verticalCompact: boolean) => TLayout;
